/*

   https://remotexy.com/en/examples/

*/


#include <Servo.h>
Servo front;
Servo mid;
Servo rear;

int minLeg = 50; // 90 = center
int maxLeg = 130;
int pos1; int pos2; int pos3; 
int lspeed =10;  //speed: 1-10
int pause = 2; // delay after each Leg


#include <ESP8266WiFi.h>
#include <RemoteXY.h>


// RemoteXY configurate  
#pragma pack(push, 1)
uint8_t RemoteXY_CONF[] =
  { 255,4,0,0,0,56,0,13,24,1,
  5,32,13,25,39,39,64,25,33,1,
  0,26,73,12,12,35,31,115,104,97,
  107,101,0,1,0,48,2,12,12,177,
  31,99,111,110,110,101,99,116,0,129,
  0,4,3,18,6,4,76,105,122,97,
  114,100,0 }; 
  
// this structure defines all the variables and events of your control interface 
struct {


    // input variables
  int8_t joystick_1_x; // =-100..100 x-coordinate joystick position 
  int8_t joystick_1_y; // =-100..100 y-coordinate joystick position 
  uint8_t button_1; // =1 if button pressed, else =0 
  uint8_t button_2; // =1 if button pressed, else =0 

    // other variable
  uint8_t connect_flag;  // =1 if wire connected, else =0 

} RemoteXY;
#pragma pack(pop)



/////////////////////////////////////////////
//           END RemoteXY include          //
/////////////////////////////////////////////


CRemoteXY *remotexy;

void setup() 
{
  Serial.begin(9600);
  
  front.attach(14);  // D5
  mid.attach(12);    // D6
  rear.attach(13);   // D7
    front.write(90); // center all servos
    mid.write(90);
    rear.write(90);
  delay(2000);
  
  remotexy = new CRemoteXY (
    RemoteXY_CONF_PROGMEM, 
    &RemoteXY, 
    "", 
    new CRemoteXYConnectionServer (
      new CRemoteXYComm_WiFiPoint (
        "RemoteXY",       // REMOTEXY_WIFI_SSID
        "1234567890"),          // REMOTEXY_WIFI_PASSWORD
      6377                  // REMOTEXY_SERVER_PORT
    )
  ); 
  Serial.println("WiFi connected");
  
  // TODO you setup code
  
}

void loop() 
{
  remotexy->handler ();

//  y= 100  ->  vorwaerts
//  y= -100  ->  rueckwaerts

//  y= +100  ->  rechts
//  y= -100  ->  links


  int x = RemoteXY.joystick_1_x;
  int y = RemoteXY.joystick_1_y;
  Serial.println(RemoteXY.joystick_1_x);
  Serial.print("           y:");
  Serial.println(RemoteXY.joystick_1_y);
if ((y>x) && (y> -x)){
  Serial.println("forward");
  forward();
}
if ((y<x) && (y < -x)){
  Serial.println("backwards");
  backward();
}
if ((x>y) && (x> -y)){
  Serial.println("right");
  right();
}
if ((x<y) && (x< -y)){
  Serial.println("left");
  left();
}

if ((RemoteXY.button_1) == 1){
  Serial.println("                   SHAKE !!");
  shake();
}
if ((x==0) && (y==0)){
  Serial.println("stop");
  stopp();
}


}



void forward() {

  Serial.println("left");
  for(pos1=minLeg; pos1<=maxLeg; pos1 +=lspeed) {
    front.write(pos1);
     pos2 = (maxLeg-pos1 + minLeg);
    rear.write(pos2);
    delay(pause);
  }
  Serial.println("             mid");
  mid.write(115);  // fine tuning may be necessary here
  delay(50);

  Serial.println("                        right");
  for(pos1=maxLeg; pos1>=minLeg; pos1 -=lspeed) {
    front.write(pos1);
     pos2 = (maxLeg-pos1 + minLeg);
    rear.write(pos2);
    delay(pause);
  }
  Serial.println("             mid");
  mid.write(55);    // fine tuning may be necessary here
  delay(50);
}


void backward() {

  for(pos1=minLeg; pos1<=maxLeg; pos1 +=lspeed) {
    front.write(pos1);
     pos2 = (maxLeg-pos1 + minLeg);
    rear.write(pos2);
    delay(pause);
  }
  mid.write(55);  // fine tuning may be necessary here
  delay(pause);

  for(pos1=maxLeg; pos1>=minLeg; pos1 -=lspeed) {
    front.write(pos1);
     pos2 = (maxLeg-pos1 + minLeg);
    rear.write(pos2);
    delay(pause);
  }
  mid.write(115);    // fine tuning may be necessary here
  delay(pause);
}



void right()
{
  for(pos1=minLeg; pos1<=maxLeg; pos1 +=lspeed) {
    front.write(pos1);
     pos2 = (maxLeg-pos1 + minLeg);
    rear.write(pos2);
    delay(pause);
  }
  mid.write(130);  // fine tuning may be necessary here
  delay(50);

  for(pos1=maxLeg; pos1>=minLeg; pos1 -=lspeed) {
    front.write(pos1);
     pos2 = (maxLeg-pos1 + minLeg);
    rear.write(pos2);
    delay(pause);
  }
  mid.write(70);    // fine tuning may be necessary here
  delay(50);
}


void left()
{
  for(pos1=minLeg; pos1<=maxLeg; pos1 +=lspeed) {
    front.write(pos1);
     pos2 = (maxLeg-pos1 + minLeg);
    rear.write(pos2);
    delay(pause);
  }
  mid.write(100);  // fine tuning may be necessary here
  delay(50);

  for(pos1=maxLeg; pos1>=minLeg; pos1 -=lspeed) {
    front.write(pos1);
     pos2 = (maxLeg-pos1 + minLeg);
    rear.write(pos2);
    delay(pause);
  }
  mid.write(40);    // fine tuning may be necessary here
  delay(50);
}


void stopp()
{
    front.write(90);
    mid.write(90);
    rear.write(90);
    delay(100);
}

void shake()
{
    mid.write(145); 
    delay(150);
    mid.write(25); 
    delay(150);
}
